#include <Servo.h> //Arduino standard library
#include <IRremote.h> //IR library
#include "Wire.h" //Wire.h for LCD (sometimes needed)
#include "LiquidCrystal_I2C.h" //LCD library

#define servopin 9 //this defines pin 9 as the pin used for the servo control lead (orange)
int RECV_PIN = 11; //IR photo-transistor sends output to pin 11 
int currentAngle = 0; //declare currentAngle integer variable and set to 0
IRrecv irrecv(RECV_PIN); //instantiate a IR receiver object
decode_results results; //instantiate a decode_results object. This object is separate from the IR receiver.

Servo myservo;  //instantiate a Servo object named 'myservo' 
                //a maximum of eight servo objects can be created

LiquidCrystal_I2C myDisplay(0x27, 16, 2); //instantiate LCD object and set up config
 
 
void setup() 
{ 
  Serial.begin(9600);        //start serial port
  myservo.attach(servopin);  //attaches the servo on pin 9 to the servo object
  irrecv.enableIRIn();       //start the receiver
  myDisplay.init();          //initialize LCD
  myDisplay.backlight();     //turn on LCD backlight
}
 
void loop() 
{
  if (irrecv.decode(&results)) //if transmission received... 
  {
    Serial.print("IR value received: ");
    Serial.println(results.value); //display value received
    //interpret the received commands...
        if (results.value == 16724175) //1
        {
          //left
          myservo.write(0);
        }
        if (results.value == 16718055) //2
        {
          //middle
          myservo.write(90);
        }
        if (results.value == 16743045) //3
        {
          //right
          myservo.write(180);
        }
        if (results.value == 16754775) //+
        {
          //increment
          currentAngle = myservo.read();
          myservo.write(currentAngle + 1);
        }
        if (results.value == 16769055) //-
        {
          //decrement
          currentAngle = myservo.read();
          myservo.write(currentAngle - 1);
        }
  }
  
  irrecv.resume(); //Receive the next value

  //Serial monitor print
  Serial.print("Current servo position: ");
  Serial.println(myservo.read()); //this retrieves the servo position and sends it to the serial monitor

  //LCD print
  myDisplay.clear();
  myDisplay.print("Servo deg.: ");
  myDisplay.print(myservo.read());
  
  delay(200); //delay to make servo actuation stable
} 
